@@ -3,8 +3,8 @@ use strict;
 use warnings;
 use warnings::register;
 
-# ABSTRACT: An extension of the File::stat module, provides additional methods
-our $VERSION = '0.001'; # VERSION
+# ABSTRACT: An extension of the File::stat module, provides additional methods.
+our $VERSION = '0.002'; # VERSION
 
 #pod =for test_synopsis
 #pod my ($st, $file);
@@ -47,14 +47,14 @@ our $VERSION = '0.001'; # VERSION
 #pod * Returns non-object result in list context.
 #pod * You can now pass in bare file handles to C<stat> and C<lstat> under C<use strict>.
 #pod * File tests C<-t> C<-T>, and C<-B> have been implemented too.
-#pod * Convenience functions C<filetype>, C<permissions> for direct access to filetype and permission parts of the mode field/
+#pod * Convenience functions C<filetype> and C<permissions> for direct access to filetype and permission parts of the mode field.
 #pod * Named access to common file tests (C<isRegular> / C<isFile>, C<isDir>, C<isLink>, C<isBlock>, C<isChar>, C<isFIFO> / C<isPipe>, C<isSocket>).
-#pod * Access to the name of the file (C<file>, C<abs_file> / C<target>).
+#pod * Access to the name of the file / file handle used for the stat (C<file>, C<abs_file> / C<target>).
 #pod
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
-#pod * L<File::stat> for the module this module extends.
+#pod * L<File::stat> for the module for which C<File::stat::Extra> is the extension.
 #pod * L<stat> and L<lstat> for the original C<stat> and C<lstat> functions.
 #pod
 #pod =head1 COMPATIBILITY
@@ -69,11 +69,13 @@ our $VERSION = '0.001'; # VERSION
 #pod
 #pod =head1 WARNINGS
 #pod
-#pod When a file (handle) can not be (l)stat-ed, a warning C<Unable to stat: %s>. To disable this warning, specify
+#pod When a file (handle) can not be (l)stat-ed, a warning C<Unable to
+#pod stat: %s>. To disable this warning, specify
 #pod
 #pod     no warnings "File::stat::Extra";
 #pod
-#pod The following warnings are inhereted from C<File::stat>, these can all be disabled with
+#pod The following warnings are inhereted from C<File::stat>, these can all
+#pod be disabled with
 #pod
 #pod     no warnings "File::stat";
 #pod
@@ -109,8 +111,7 @@ use Cwd ();
 use Fcntl ();
 
 require Carp;
-$Carp::Internal{+__PACKAGE__}++; # To get warnings reported at correct caller level
-
+$Carp::Internal{ (__PACKAGE__) }++; # To get warnings reported at correct caller level
 
 #pod =func stat( I<FILEHANDLE> )
 #pod
@@ -450,11 +451,11 @@ __END__
 
 =head1 NAME
 
-File::stat::Extra - An extension of the File::stat module, provides additional methods
+File::stat::Extra - An extension of the File::stat module, provides additional methods.
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -506,7 +507,7 @@ File tests C<-t> C<-T>, and C<-B> have been implemented too.
 
 =item *
 
-Convenience functions C<filetype>, C<permissions> for direct access to filetype and permission parts of the mode field/
+Convenience functions C<filetype> and C<permissions> for direct access to filetype and permission parts of the mode field.
 
 =item *
 
@@ -514,7 +515,7 @@ Named access to common file tests (C<isRegular> / C<isFile>, C<isDir>, C<isLink>
 
 =item *
 
-Access to the name of the file (C<file>, C<abs_file> / C<target>).
+Access to the name of the file / file handle used for the stat (C<file>, C<abs_file> / C<target>).
 
 =back
 
@@ -659,11 +660,13 @@ file.
 
 =head1 WARNINGS
 
-When a file (handle) can not be (l)stat-ed, a warning C<Unable to stat: %s>. To disable this warning, specify
+When a file (handle) can not be (l)stat-ed, a warning C<Unable to
+stat: %s>. To disable this warning, specify
 
     no warnings "File::stat::Extra";
 
-The following warnings are inhereted from C<File::stat>, these can all be disabled with
+The following warnings are inhereted from C<File::stat>, these can all
+be disabled with
 
     no warnings "File::stat";
 
@@ -709,7 +712,7 @@ available. This may change in a future version of this module.
 
 =item *
 
-L<File::stat> for the module this module extends.
+L<File::stat> for the module for which C<File::stat::Extra> is the extension.
 
 =item *
 
